export interface Encoder {
    stringify(wordArray: WordArray): string;
    parse(str: string): WordArray;
}
export interface WordArray {
    words: number[];
    sigBytes: number;
    toString(encoder?: Encoder): string;
    concat(wordArray: WordArray): this;
    clamp(): void;
    clone(): WordArray;
}
export interface Hasher {
    reset(): void;
    update(messageUpdate: WordArray | string): this;
    finalize(messageUpdate?: WordArray | string): WordArray;
}
export interface IUseHashFileReturn {
    isHashLoading: boolean;
    isHashError: boolean;
    sha256: string | null;
    sha1: string | null;
    md5: string | null;
    timeSpend: number | null;
}
/**
 * hash文件
 * @param file 需要计算的文件
 * @param hashAlgo hash 计算的算法 'md5' |'sha1'| 'sha256'  默认为 sha256
 * @param chunkSizeCustom   分块大小 默认为 10M
 * @return IUseHashFileReturn
 */
declare const useHashCode: (file: File | null, hashAlgo?: "md5" | "sha1" | "sha256" | undefined, chunkSizeCustom?: number | undefined) => IUseHashFileReturn;
export default useHashCode;
